@@ -436,6 +436,14 @@ read_config(AppletConfig *config){
 	config->font = g_strdup(tmp);
 	g_free(tmp);
     }
+   /* Get background color. */
+    tmp = NULL;
+    tmp = gconf_client_get_string(gconf_client,
+                                    GCONF_KEY_WEATHER_BACKGROUND_COLOR, NULL);
+    if(!tmp || !gdk_color_parse(tmp, &(config->background_color)))
+        config->background_color = DEFAULT_FONT_COLOR;
+    g_free(tmp);
+    tmp = NULL;
 
     #ifndef OS2008
 	/* Get Enable Transparency flag. Default is TRUE. */
@@ -790,7 +798,14 @@ config_save(AppletConfig *config){
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_SEPARATE_DATA,
 			config->separate, NULL);
-
+     /* Save Background Color */
+    sprintf(temp_buffer, "#%02x%02x%02x",
+                         config->background_color.red >> 8,
+                         config->background_color.green >> 8,
+                         config->background_color.blue >> 8);
+    gconf_client_set_string(gconf_client,
+                         GCONF_KEY_WEATHER_BACKGROUND_COLOR,
+                         temp_buffer, NULL);
      /* Save Downloading after connecting State */
     gconf_client_set_bool(gconf_client,
         		GCONF_KEY_DOWNLOADING_AFTER_CONNECTING,
