@@ -464,15 +464,20 @@ void draw_home_window(gint count_day){
 			sprintf(buffer_icon, "%s48.png", path_large_icon);
 		    }
 		    else{ /* if first day and not config->separate data */
-			create_day_temperature_text(day, buffer, FALSE, FALSE);
-			/* displaying wind if necessary */    
-			if(app->config->show_wind)
-			    add_wind_text(day, buffer + strlen(buffer));
 			/* if current time is night show night icon */
-			if(current_time > night_begin_time && current_time < day_begin_time)
+			if(current_time > night_begin_time || current_time < day_begin_time){
+			    create_day_temperature_text(day, buffer, FALSE, FALSE);
+			    /* displaying wind if necessary */    
+			    if(app->config->show_wind)
+				add_wind_text(day, buffer + strlen(buffer),FALSE);
 			    sprintf(buffer_icon, "%s%s.png", path_large_icon, item_value(day, "night_icon"));
-			else
+			}else{
+			    create_day_temperature_text(day, buffer, FALSE, FALSE);
+			    /* displaying wind if necessary */    
+			    if(app->config->show_wind)
+				add_wind_text(day, buffer + strlen(buffer),TRUE);
 			    sprintf(buffer_icon, "%s%s.png", path_large_icon, item_value(day, "day_icon"));
+			}
 		    }
 		}
 	    }
@@ -480,10 +485,18 @@ void draw_home_window(gint count_day){
 		buffer[0] = 0;
 		(app->config->separate && i == 1) ? (tmp_day = first) : (tmp_day = day);
 		create_day_temperature_text(tmp_day, buffer, FALSE, FALSE);
-		if(app->config->show_wind)
-		    add_wind_text(tmp_day, buffer + strlen(buffer));
-		sprintf(buffer_icon, "%s%s.png", path_large_icon,
+		if((app->config->separate) && (i == 1) &&
+		   (current_time > night_begin_time || current_time < day_begin_time)){
+		    if(app->config->show_wind)
+			add_wind_text(tmp_day, buffer + strlen(buffer),FALSE);
+		    sprintf(buffer_icon, "%s%s.png", path_large_icon,
+			item_value(tmp_day, "night_icon"));
+		}else{
+		    if(app->config->show_wind)
+			add_wind_text(tmp_day, buffer + strlen(buffer),TRUE);
+		    sprintf(buffer_icon, "%s%s.png", path_large_icon,
 			item_value(tmp_day, "day_icon"));
+		}	
 	    }
 	}
 	else{ /* Show N/A for all others day buttons when it not inside range */
@@ -517,7 +530,8 @@ void draw_home_window(gint count_day){
 						    app->config->transparency,
 						    TRUE,
 						    &(app->config->background_color));
-	g_signal_connect(tmp_button->button, "button-release-event",
+//	g_signal_connect(tmp_button->button, "button-release-event",
+	g_signal_connect(tmp_button->button, "button-press-event",
 			    G_CALLBACK(weather_window_popup),
 			    (is_na_day ? (GINT_TO_POINTER(-1)) : (GINT_TO_POINTER(i))));
 	add_item2object(&(app->buttons), (void*)tmp_button);
@@ -1626,31 +1640,46 @@ time_t get_day_part_begin_time(GSList *day, guint year, const gchar *day_part){
     return  mktime(&tm);
 }
 /*******************************************************************************/
-void add_wind_text(GSList *day, gchar *buffer){
+void add_wind_text(GSList *day, gchar *buffer, gboolean is_day){
     gchar	*wind_direction = NULL;
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
-    if(strcmp((char*)item_value(day, "day_wind_speed"), "N/A")){
-	if(!strcmp((char*)item_value(day, "day_wind_title"), "N/A"))
-	    wind_direction = _("N/A");
-	else
-	    wind_direction = (char*)hash_table_find(item_value(day, "day_wind_title"), TRUE);
-	sprintf(buffer + strlen(buffer),
-		"<span foreground='#%02x%02x%02x'>\n%s\n%.1f</span>",
-		app->config->font_color.red >> 8,
-		app->config->font_color.green >> 8,
-		app->config->font_color.blue >> 8,
-		wind_direction,
-		convert_wind_units(app->config->wind_units, atof(item_value(day, "day_wind_speed"))));
-    }
-    else
+
+    if( (is_day && !strcmp((char*)item_value(day, "day_wind_speed"), "N/A"))||
+	!strcmp((char*)item_value(day, "night_wind_speed"), "N/A")){
 	sprintf(buffer + strlen(buffer),
 		"<span foreground='#%02x%02x%02x'>\n%s\n%s</span>",
 		app->config->font_color.red >> 8,
 		app->config->font_color.green >> 8,
 		app->config->font_color.blue >> 8,
 		_("N/A"), _("N/A"));
+    }
+    else{
+    	if((is_day && !strcmp((char*)item_value(day, "day_wind_title"), "N/A"))||
+    	    !strcmp((char*)item_value(day, "night_wind_title"), "N/A"))
+	    wind_direction = _("N/A");
+	else
+	    if (is_day){
+		wind_direction = (char*)hash_table_find(item_value(day, "day_wind_title"), TRUE);
+		sprintf(buffer + strlen(buffer),
+		    "<span foreground='#%02x%02x%02x'>\n%s\n%.1f</span>",
+		    app->config->font_color.red >> 8,
+		    app->config->font_color.green >> 8,
+		    app->config->font_color.blue >> 8,
+		    wind_direction,
+		    convert_wind_units(app->config->wind_units, atof(item_value(day, "day_wind_speed"))));
+	    }else{
+		wind_direction = (char*)hash_table_find(item_value(day, "night_wind_title"), TRUE);
+		sprintf(buffer + strlen(buffer),
+		    "<span foreground='#%02x%02x%02x'>\n%s\n%.1f</span>",
+		    app->config->font_color.red >> 8,
+		    app->config->font_color.green >> 8,
+		    app->config->font_color.blue >> 8,
+		    wind_direction,
+		    convert_wind_units(app->config->wind_units, atof(item_value(day, "night_wind_speed"))));
+	    }
+    }
 }
 /*******************************************************************************/
 void create_current_temperature_text(GSList *day, gchar *buffer, gboolean valid,
