@@ -312,7 +312,7 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 	current_tab = gtk_vbox_new(FALSE, 0);
 
     if(current_tab){
-	if(active_tab == 0 && app->config->separate)
+	if(active_tab == 0)
         {
     	    gtk_notebook_append_page(GTK_NOTEBOOK(notebook),
 				current_tab,
@@ -397,10 +397,10 @@ gboolean weather_window_popup(GtkWidget *widget, GdkEvent *event,
 			(gpointer)app->popup_window);
 
 /* Pack buttons to the buttons box */
-    gtk_box_pack_start(GTK_BOX(buttons_box), settings_button, FALSE, FALSE, 60);
+    gtk_box_pack_start(GTK_BOX(buttons_box), settings_button, TRUE, TRUE, 5);
     gtk_box_pack_start(GTK_BOX(buttons_box), refresh_button, TRUE, TRUE, 5);
     gtk_box_pack_start(GTK_BOX(buttons_box), about_button, TRUE, TRUE, 5);
-    gtk_box_pack_start(GTK_BOX(buttons_box), close_button, FALSE, FALSE, 60);
+    gtk_box_pack_start(GTK_BOX(buttons_box), close_button, TRUE, TRUE, 5);
 
     /* check if no data file for this station */
     if(gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook)) > 0){
